@@ -9,6 +9,7 @@ Maintained by James Stewart since 2021
 Library for communicating with the BES (BigFix) REST API.
 """
 
+import configparser
 import datetime
 import json
 import logging
@@ -17,8 +18,6 @@ import random
 import site
 import string
 
-# import urllib3.poolmanager
-
 try:
     from urllib import parse
 except ImportError:
@@ -78,7 +77,6 @@ def elem2dict(node):
         else:
             value = elem2dict(element)
         if key in result:
-
             if type(result[key]) is list:
                 result[key].append(value)
             else:
@@ -113,6 +111,7 @@ def parse_bes_modtime(string_datetime):
     return datetime.datetime.strptime(string_datetime, "%a, %d %b %Y %H:%M:%S %z")
 
 
+# import urllib3.poolmanager
 # # https://docs.python-requests.org/en/latest/user/advanced/#transport-adapters
 # class HTTPAdapterBiggerBlocksize(requests.adapters.HTTPAdapter):
 #     """custom HTTPAdapter for requests to override blocksize
@@ -150,11 +149,52 @@ def parse_bes_modtime(string_datetime):
 #         )
 
 
+def get_bes_conn_using_config_file(conf_file=None):
+    """
+    read connection values from config file
+    return besapi connection
+    """
+    config_paths = [
+        "/etc/besapi.conf",
+        os.path.expanduser("~/besapi.conf"),
+        os.path.expanduser("~/.besapi.conf"),
+        "besapi.conf",
+    ]
+    # if conf_file specified, then only use that:
+    if conf_file:
+        config_paths = [conf_file]
+
+    configparser_instance = configparser.ConfigParser()
+
+    found_config_files = configparser_instance.read(config_paths)
+
+    if found_config_files and configparser_instance:
+        print("Attempting BESAPI Connection using config file:", found_config_files)
+        try:
+            BES_ROOT_SERVER = configparser_instance.get("besapi", "BES_ROOT_SERVER")
+        except BaseException:
+            BES_ROOT_SERVER = None
+
+        try:
+            BES_USER_NAME = configparser_instance.get("besapi", "BES_USER_NAME")
+        except BaseException:
+            BES_USER_NAME = None
+
+        try:
+            BES_PASSWORD = configparser_instance.get("besapi", "BES_PASSWORD")
+        except BaseException:
+            BES_PASSWORD = None
+
+        if BES_ROOT_SERVER and BES_USER_NAME and BES_PASSWORD:
+            return BESConnection(BES_USER_NAME, BES_PASSWORD, BES_ROOT_SERVER)
+
+    return None
+
+
 class BESConnection:
     """BigFix RESTAPI connection abstraction class"""
 
     def __init__(self, username, password, rootserver, verify=False):
-
         if not verify:
             # disable SSL warnings
             requests.packages.urllib3.disable_warnings()  # pylint: disable=no-member
@@ -463,6 +503,32 @@ class BESConnection:
 
         return self.get_computergroup(site_path, new_group_name)
 
+    def get_upload(self, file_name, file_hash):
+        """
+        check for a specific file upload reference
+
+        each upload is uniquely identified by sha1 and filename
+
+        - https://developer.bigfix.com/rest-api/api/upload.html
+        - https://github.com/jgstew/besapi/issues/3
+        """
+        if len(file_hash) != 40:
+            raise ValueError("Invalid SHA1 Hash! Must be 40 characters!")
+
+        if " " in file_hash or " " in file_name:
+            raise ValueError("file name and hash cannot contain spaces")
+
+        if len(file_name) > 0:
+            result = self.get(self.url("upload/" + file_hash + "/" + file_name))
+        else:
+            raise ValueError("No file_name specified. Must be at least one character.")
+
+        if "Upload not found" in result.text:
+            # print("WARNING: Upload not found!")
+            return None
+
+        return result
+
     def upload(self, file_path, file_name=None):
         """
         upload a single file
